@@ -25,6 +25,7 @@ PHP_METHOD(RedisArray, flushall);
 PHP_METHOD(RedisArray, mget);
 PHP_METHOD(RedisArray, mset);
 PHP_METHOD(RedisArray, del);
+PHP_METHOD(RedisArray, unlink);
 PHP_METHOD(RedisArray, keys);
 PHP_METHOD(RedisArray, getOption);
 PHP_METHOD(RedisArray, setOption);
@@ -39,20 +40,20 @@ PHP_METHOD(RedisArray, unwatch);
 
 typedef struct RedisArray_ {
 
-	int count;
-	char **hosts;			/* array of host:port strings */
-	zval *redis;			/* array of Redis instances */
-	zval *z_multi_exec;		/* Redis instance to be used in multi-exec */
-	zend_bool index;		/* use per-node index */
-	zend_bool auto_rehash; 	/* migrate keys on read operations */
-	zend_bool pconnect;     /* should we use pconnect */
-	zval z_fun;             /* key extractor, callable */
-	zval z_dist;            /* key distributor, callable */
-	zval z_pure_cmds;		/* hash table */
-	double connect_timeout; /* socket connect timeout */
-	double read_timeout;    /* socket read timeout */
+    int count;
+    char **hosts;           /* array of host:port strings */
+    zval *redis;            /* array of Redis instances */
+    zval *z_multi_exec;     /* Redis instance to be used in multi-exec */
+    zend_bool index;        /* use per-node index */
+    zend_bool auto_rehash;  /* migrate keys on read operations */
+    zend_bool pconnect;     /* should we use pconnect */
+    zval z_fun;             /* key extractor, callable */
+    zval z_dist;            /* key distributor, callable */
+    HashTable *pure_cmds;   /* hash table */
+    double connect_timeout; /* socket connect timeout */
+    double read_timeout;    /* socket read timeout */
 
-	struct RedisArray_ *prev;
+    struct RedisArray_ *prev;
 } RedisArray;
 
 #if (PHP_MAJOR_VERSION < 7)
